<!DOCTYPE TS><TS>
<context>
    <name>AddMeta</name>
    <message>
        <source>Insert a:</source>
        <translation>Inserir um(a):</translation>
    </message>
    <message>
        <source>&amp;Marker</source>
        <translation>&amp;Marcador</translation>
    </message>
    <message>
        <source>Voice &amp;Track</source>
        <translation>&amp;Faixa de Voz</translation>
    </message>
    <message>
        <source>Log C&amp;hain</source>
        <translation>Corrente de Lista</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>EditChain</name>
    <message>
        <source>Edit Log Chain</source>
        <translation>Editar Corrente de Lista</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Inicie às:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>
Ação se Evento anterior estiver sendo executado</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Iniciar Imediatamente</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Ser Próxima</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Esperar até</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Simples</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Pare</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation>Tipo de Transição:</translation>
    </message>
    <message>
        <source>Log Name</source>
        <translation>Nome da Lista</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Selecionar</translation>
    </message>
    <message>
        <source>Log Description</source>
        <translation>Descrição da Lista</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Transição de Cartão anterior terminar antes</translation>
    </message>
</context>
<context>
    <name>EditLog</name>
    <message>
        <source>Edit Log</source>
        <translation>Editar Lista</translation>
    </message>
    <message>
        <source>Log Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Tracks:</source>
        <translation>Faixas:</translation>
    </message>
    <message>
        <source>Origin:</source>
        <translation>Origem:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Delete on</source>
        <translation>Deletar</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Sel</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Serviço:</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <source>Enable AutoRefresh:</source>
        <translation>Habilitar AutoAtualização:</translation>
    </message>
    <message>
        <source>Start Date:</source>
        <translation>Data de Início:</translation>
    </message>
    <message>
        <source>End Date:</source>
        <translation>Data de Término:</translation>
    </message>
    <message>
        <source>Start Date Enabled</source>
        <translation>Data de Início habilitada</translation>
    </message>
    <message>
        <source>End Date Enabled</source>
        <translation>Data de Término hab</translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation>Duração </translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation>Até PARE:</translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation>Até FIM:</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation>HORA</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation>TRANS</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>CARTÃO</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPO</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>DURAÇÃO</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TÍTULO</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>ARTISTA</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation>CLIENTE</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation>AGÊNCIA</translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation>SELO</translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation>FONTE</translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation>ID DE LINHA</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation>CONTADOR</translation>
    </message>
    <message>
        <source>Insert
Cart</source>
        <translation>Inserir
Cartão</translation>
    </message>
    <message>
        <source>Insert
Meta</source>
        <translation>Inserir
Meta
</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Deletar</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salvar</translation>
    </message>
    <message>
        <source>Save
&amp;As</source>
        <translation>&amp;Salvar
Como</translation>
    </message>
    <message>
        <source>&amp;Reports</source>
        <translation>&amp;Relatórios</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Invalid Carts</source>
        <translation>Cartões Inválidos</translation>
    </message>
    <message>
        <source>This log contains one or more carts
that are invalid for the selected service!</source>
        <translation>A Lista contém um ou mais cartões
que são inválidos para o serviço selecionado!</translation>
    </message>
    <message>
        <source>Voice Track</source>
        <translation>Faixa de Voz</translation>
    </message>
    <message>
        <source>The log contains carts that are disabled
for the selected service!

Do you still want to save?</source>
        <translation>A Lista contém cartões que estão desabilitados
para o serviço selecionado!

Você ainda quer salvar?</translation>
    </message>
    <message>
        <source>Add Log</source>
        <translation>Adicionar Lista</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>Lista Existente</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation>Lista já Existe!</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation>RDListas</translation>
    </message>
    <message>
        <source>The log has been modified.
Do you want to save your changes?</source>
        <translation>A Lista foi modificada.
Você quer salvar suas mudanças?</translation>
    </message>
    <message>
        <source>The log contains carts that are disabled
for the selected service!</source>
        <translation>A Lista contém cartões que estão desabilitados
para o serviço selecionado!</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>SIMPLES</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>PARE</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SOBRE</translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation>[cartão não encontrado]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARCADOR</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>FAIXA</translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation>CORRENTE DE LISTA</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LINK</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[importar músicas]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[importar tráfego]</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation>Tráfego</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Músicas</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDControle</translation>
    </message>
    <message>
        <source>Voice Tracker</source>
        <translation>Faixas de Voz</translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation>-- fim da lista--</translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation>Selecionado:</translation>
    </message>
    <message>
        <source>[INVALID CART]</source>
        <translation>CARTÃO INVÁLIDO</translation>
    </message>
    <message>
        <source>Unable to save log, audio deletion error!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditLogLine</name>
    <message>
        <source>Edit Log Entry</source>
        <translation>Editar Entrada na Lista</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Inicie às:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Ação se Evento anterior estiver sendo executado</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Iniciar Imediatamente</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Ser Próxima</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Esperar até</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Simples</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Pare</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation>Tipo de Transição:</translation>
    </message>
    <message>
        <source>No Fade on Segue Out</source>
        <translation>Sem Fade na Saída SOBRE</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Cartão</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Select
Cart</source>
        <translation>Selecionar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Transição de Cartão anterior terminar antes</translation>
    </message>
    <message>
        <source>Missing Cart</source>
        <translation>Cartão Faltando</translation>
    </message>
    <message>
        <source>You must supply a cart number!</source>
        <translation>Você deve dar um número ao Cartão!</translation>
    </message>
    <message>
        <source>Disabled Cart</source>
        <translation>Cartão Desabilitado</translation>
    </message>
    <message>
        <source>This cart belongs to a disabled
group for the specified service!</source>
        <translation>Este cartão pertence a um grupo desabilitado
para o Serviço especificado!</translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation>Duplicar Hora de Início</translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation>Um evento já foi agendado para esta hora!</translation>
    </message>
</context>
<context>
    <name>EditMarker</name>
    <message>
        <source>Edit Log Marker</source>
        <translation>Editar Marcador de Lista</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Inicie às:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Ação se Evento anterior estiver sendo executado</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Iniciar Imediatamente</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Ser Próxima</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Esperar até</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Simples</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Pare</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Selo</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Transição se Cartão anterior terminar antes</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation>Tipo de Transição:</translation>
    </message>
</context>
<context>
    <name>EditTrack</name>
    <message>
        <source>Edit Voice Track Marker</source>
        <translation>Editar Marcador de Faixa de Voz</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Inicie às:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>
Ação se Evento anterior estiver sendo executado</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Iniciar Imediatamente</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Ser Próxima</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Esperar até</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Simples</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Pare</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Transição de Cartão anterior terminar antes</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation>Tipo de Transição:</translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation>Selecionar a Lista</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NOME</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>DESCRIÇÃO</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>SERVIÇO</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation>Relatórios da RDBiblio</translation>
    </message>
    <message>
        <source>Log Listing</source>
        <translation>Descrição da Lista</translation>
    </message>
    <message>
        <source>Log Exception Report</source>
        <translation>Relatório de Exceção de Lista</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Effective Date:</source>
        <translation>Data Efetiva:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Selecionar</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation>&amp;Gerar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[nenhum]</translation>
    </message>
    <message>
        <source>Log Check</source>
        <translation>Checar Lista</translation>
    </message>
    <message>
        <source>No exceptions found.</source>
        <translation>Exceções não Encontradas.</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogEdit - Host</source>
        <translation type="obsolete">RDListas - Cliente</translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation type="obsolete">Usuário: [Desconhecido] </translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Não foi possível Conectar</translation>
    </message>
    <message>
        <source>LOG NAME</source>
        <translation>NOME DA LISTA</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>DESCRIÇÃO</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>SERVIÇO</translation>
    </message>
    <message>
        <source>MUSIC</source>
        <translation>MÚSICAS</translation>
    </message>
    <message>
        <source>TRAFFIC</source>
        <translation>TRÁFEGO</translation>
    </message>
    <message>
        <source>TRACKS</source>
        <translation>FAIXAS</translation>
    </message>
    <message>
        <source>VALID FROM</source>
        <translation>VÁLIDO A PARTIR DE</translation>
    </message>
    <message>
        <source>VALID TO</source>
        <translation>VÁLIDO ATÉ</translation>
    </message>
    <message>
        <source>AUTO REFRESH</source>
        <translation>AUTO ATUALIZAÇÃO</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation>ORIGEM</translation>
    </message>
    <message>
        <source>LAST LINKED</source>
        <translation>ÚLTIMO LINKADO</translation>
    </message>
    <message>
        <source>LAST MODIFIED</source>
        <translation>ÚLTIMO MODIFICADO</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Deletar</translation>
    </message>
    <message>
        <source>Voice
&amp;Tracker</source>
        <translation>&amp;Editar
Faixa de Voz</translation>
    </message>
    <message>
        <source>Log
Report</source>
        <translation>Relatório</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuário</translation>
    </message>
    <message>
        <source>Add Log</source>
        <translation>Adicionar Lista</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>Lista Existente</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation>Lista já Existe!</translation>
    </message>
    <message>
        <source>Delete Log</source>
        <translation>Deletar Lista</translation>
    </message>
    <message>
        <source>This will also delete the</source>
        <translation>Esta ação também deletarará @</translation>
    </message>
    <message>
        <source>voice tracks associated with this log.
Continue?</source>
        <translation>faixas de voz associadas a esta Lista.
Continuar?</translation>
    </message>
    <message>
        <source>Tracks Exist</source>
        <translation>Faixa Existente</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation></translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation type="unfinished">RDListas</translation>
    </message>
    <message>
        <source>Unable to delete log, audio deletion error!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit -- Database Skew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This version of RDLogEdit is incompatible with the version installed on the server.
See your system administrator for an update!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VoiceTracker</name>
    <message>
        <source>Voice Tracker</source>
        <translation type="unfinished">Faixas de Voz</translation>
    </message>
    <message>
        <source>Edit Cue Markers</source>
        <translation type="unfinished">Editar Marcador de Escuta</translation>
    </message>
    <message>
        <source>Undo Segue Changes</source>
        <translation type="unfinished">Desfazer Mudanças de Sobre</translation>
    </message>
    <message>
        <source>Set Start Point Here</source>
        <translation type="unfinished">Marcar Início aqui</translation>
    </message>
    <message>
        <source>Set End Point Here</source>
        <translation type="unfinished">Marcar Término aqui</translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Comece</translation>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished">Gravar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished">Salvar</translation>
    </message>
    <message>
        <source>&amp;Previous
Track</source>
        <translation type="unfinished">&amp;Última
Faixa</translation>
    </message>
    <message>
        <source>&amp;Next
Track</source>
        <translation type="unfinished">&amp;Próxima
Faixa</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation type="unfinished">Faltando</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation type="unfinished">Faixas</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished">Tempo</translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"> </translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="unfinished">HORA</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="unfinished">TRANS</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="unfinished">CARTÃO</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="unfinished">GRUPO</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="unfinished">DURAÇÃO</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="unfinished">TÍTULO</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="unfinished">ARTISTA</translation>
    </message>
    <message>
        <source>Do Over</source>
        <translation type="unfinished">Gravar
por cima</translation>
    </message>
    <message>
        <source>Hit Post</source>
        <translation type="unfinished">Chegue no
Marcador</translation>
    </message>
    <message>
        <source>Insert
Track</source>
        <translation type="unfinished">Inserir
Faixa</translation>
    </message>
    <message>
        <source>Delete
Track</source>
        <translation type="unfinished">Deletar
Faixa</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Fechar</translation>
    </message>
    <message>
        <source>No VoiceTrack Group</source>
        <translation type="unfinished">Não há Grupo para Faixa de Voz</translation>
    </message>
    <message>
        <source>No voicetracking group has been defined for this service,
therefore only existing transitions will be editable.</source>
        <translation type="unfinished">Não foi definido um grupo para faixas de voz neste serviço,
Assim sendo, somente transições existentes serão editáveis.</translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished">Importar</translation>
    </message>
    <message>
        <source>Cart Creation Failure</source>
        <translation type="unfinished">Falha na criação de Cartão</translation>
    </message>
    <message>
        <source>Unable to create new cart for voice track!</source>
        <translation type="unfinished">Não foi possível criar um novo cartão para esta faixa de voz!</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished">FAIXA</translation>
    </message>
    <message>
        <source>Voice Track</source>
        <translation type="unfinished">Faixa de Voz</translation>
    </message>
    <message>
        <source>Track List</source>
        <translation type="unfinished">Lista de Faixas</translation>
    </message>
    <message>
        <source>No more tracks!</source>
        <translation type="unfinished">Não há mais faixas!</translation>
    </message>
    <message>
        <source>[end of log]</source>
        <translation type="unfinished">[Fim da Lista]</translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation type="unfinished">[cartão não encontrado]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation type="unfinished">MARCADOR</translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation type="unfinished">CORRENTE DE LISTA</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation type="unfinished">ENLACE</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation type="unfinished">[importar de música]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation type="unfinished">[importar de tráfego]</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished">SIMPLES</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished">SOBRE</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">PARE</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished">Abortar</translation>
    </message>
    <message>
        <source>Segue Changed</source>
        <translation type="unfinished">Sobre Modificado</translation>
    </message>
    <message>
        <source>Save segue changes?</source>
        <translation type="unfinished">Salvar mudanças nos &quot;Sobres&quot;?</translation>
    </message>
    <message>
        <source>Set to Hook Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation type="unfinished">RDListas</translation>
    </message>
    <message>
        <source>Audio Deletion Error!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
